==> edw_healthcheck-8.x-1.3.tar.gz: edw_healthcheck/src/Controller/EDWHealthcheckPageController.php <==
<?php
/**
 * Created by PhpStorm.
 * User: stefan
 * Date: 7/13/18
 * Time: 10:19 AM
 */

namespace Drupal\edw_healthcheck\Controller;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\edw_healthcheck\Render\JsonEDWHealthCheckRender;
use Symfony\Component\HttpFoundation\Response;
use Drupal\Core\Site\Settings;

/**
 * Class EDWHealthcheckPageController.
 *
 * Produces the HTTP output that the bash script understands.
 *
 * @package Drupal\edw_healthcheck\Controller
 */
class EDWHealthcheckPageController extends ControllerBase {

  /**
   * The EDWHealthCheck plugin manager.
   *
   * We use this to get all of the EDWHealthCheck plugins.
   *
   * @var \Drupal\edw_healthcheck\EDWHealthCheckPluginManager
   */
  protected $pluginManager;

  /**
   * The EDWHealthCheck module's config.
   *
   * We use this to get all of the EDWHealthCheck configuration settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructor.
   */
  public function __construct() {
    $this->pluginManager = \Drupal::service('plugin.manager.edw_healthcheck');
    $this->config = \Drupal::config('edw_healthcheck.settings');
  }

  /**
   * Main function building the string to show via HTTP.
   *
   * @param string $topic
   *   Optional parameter that can specify the information needed for rendering.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns an Http Response containing the processed output by the module.
   *
   * @throws PluginException
   *    The Plugin Exception needs to be handled.
   */
  public function content($topic = NULL) {
    $output = '';

    if ($this->config->get('edw_healthcheck.statuspage.enabled')) {
      if ($topic == 'all') {
        $data = array_merge($this->getPluginData('core'), $this->getPluginData('modules'), $this->getPluginData('themes'), $this->getPluginData('last_cron'));
      }
      else {
        $data = $this->getPluginData($topic);
      }

      $render_instance = new JsonEDWHealthCheckRender();
      $output .= $render_instance->render($data);

    }
    else {
      // This is not an authorized unique id or user,
      // so just return this default status.
      $output .= "UNAUTHORIZED ACCESS!";
    }

    $response = new Response($output, Response::HTTP_OK, ['Content-Type' => 'text/json']);

    // Disable browser cache:
    $response->setMaxAge(0);
    $response->setExpires();

    return $response;
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return AccessResult
   *   Returns an access result.
   */
  public function access(AccountInterface $account) {
    $allowed = FALSE;
    $request = \Drupal::request();
    if (($request->getUser() == $this->config->get('hc_user') && $request->getPassword() == $this->config->get('hc_password')) || $account->hasPermission('edw healthcheck access')) {
      $allowed = TRUE;
    }
    return AccessResult::allowedIf($allowed);
  }

  /**
   * Reusable method.
   *
   * @param string $type
   *    The type of the component that needs to be handled.
   *
   * @return array
   *    The data array processed by the plugin.
   *
   * @throws PluginException
   *    The createInstance method of the Plugin Manager can throw a Plugin
   *    Exception.
   */
  protected function getPluginData($type) {
    if (!in_array($type, ['core', 'modules', 'themes', 'last_cron'])) {
      return [];
    }
    $data = [];
    if ($this->config->get('edw_healthcheck.components.' . $type . '.enabled')) {
      $plugin = $this->pluginManager->createInstance($type . '_edw_healthcheck');
      $data = $plugin->getData();
    }
    return $data;
  }
}

==> edw_healthcheck-8.x-1.4.tar.gz: edw_healthcheck/src/Controller/EDWHealthcheckPageController.php <==
<?php
/**
 * Created by PhpStorm.
 * User: stefan
 * Date: 7/13/18
 * Time: 10:19 AM
 */

namespace Drupal\edw_healthcheck\Controller;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\edw_healthcheck\Render\JsonEDWHealthCheckRender;
use Symfony\Component\HttpFoundation\Response;
use Drupal\Core\Site\Settings;

/**
 * Class EDWHealthcheckPageController.
 *
 * Produces the HTTP output that the bash script understands.
 *
 * @package Drupal\edw_healthcheck\Controller
 */
class EDWHealthcheckPageController extends ControllerBase {

  /**
   * The EDWHealthCheck plugin manager.
   *
   * We use this to get all of the EDWHealthCheck plugins.
   *
   * @var \Drupal\edw_healthcheck\EDWHealthCheckPluginManager
   */
  protected $pluginManager;

  /**
   * The EDWHealthCheck module's config.
   *
   * We use this to get all of the EDWHealthCheck configuration settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Constructor.
   */
  public function __construct() {
    $this->pluginManager = \Drupal::service('plugin.manager.edw_healthcheck');
    $this->config = \Drupal::config('edw_healthcheck.settings');
  }

  /**
   * Main function building the string to show via HTTP.
   *
   * @param string $topic
   *   Optional parameter that can specify the information needed for rendering.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   Returns an Http Response containing the processed output by the module.
   *
   * @throws PluginException
   *    The Plugin Exception needs to be handled.
   */
  public function content($topic = NULL) {
    $output = '';

    if ($this->config->get('edw_healthcheck.statuspage.enabled')) {
      if ($topic == 'all') {
        $data = array_merge($this->getPluginData('core'), $this->getPluginData('modules'), $this->getPluginData('themes'), $this->getPluginData('last_cron'));
      }
      else {
        $data = $this->getPluginData($topic);
      }

      $render_instance = new JsonEDWHealthCheckRender();
      $output .= $render_instance->render($data);

    }
    else {
      // This is not an authorized unique id or user,
      // so just return this default status.
      $output .= "UNAUTHORIZED ACCESS!";
    }

    $response = new Response($output, Response::HTTP_OK, ['Content-Type' => 'text/json']);

    // Disable browser cache:
    $response->setMaxAge(0);
    $response->setExpires();

    return $response;
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return AccessResult
   *   Returns an access result.
   */
  public function access(AccountInterface $account) {
    $allowed = FALSE;
    $request = \Drupal::request();
    // Check if there is an incoming request and if it respects the user and password set in the configuration settings
    if(!empty($request->getUser() && ($request->getUser() == $this->config->get('hc_user') && $request->getPassword() == $this->config->get('hc_password'))){
      $allowed = true;
    }
    // Otherwise, check if the user is already logged into the application and has the necessary permission
    // to access the EDW HealthCheck information
    elseif ($account->hasPermission('edw healthcheck access')) {
      $allowed = TRUE;
    }
    return AccessResult::allowedIf($allowed);
  }

  /**
   * Reusable method.
   *
   * @param string $type
   *    The type of the component that needs to be handled.
   *
   * @return array
   *    The data array processed by the plugin.
   *
   * @throws PluginException
   *    The createInstance method of the Plugin Manager can throw a Plugin
   *    Exception.
   */
  protected function getPluginData($type) {
    if (!in_array($type, ['core', 'modules', 'themes', 'last_cron'])) {
      return [];
    }
    $data = [];
    if ($this->config->get('edw_healthcheck.components.' . $type . '.enabled')) {
      $plugin = $this->pluginManager->createInstance($type . '_edw_healthcheck');
      $data = $plugin->getData();
    }
    return $data;
  }
}
